#include <Adafruit_CircuitPlayground.h>

const int stretchSensorPin = A2;  // Stretch sensor connected to A2
const int minSensorValue = 470;   // Adjust based on testing
const int maxSensorValue = 530;   // Adjust based on testing

// External NeoPixel strip settings
#define LED_PIN A3        // Pin for the external NeoPixel strip
#define NUM_LEDS 30       // Number of LEDs on the external strip

// Create a NeoPixel strip object
Adafruit_CPlay_NeoPixel strip = Adafruit_CPlay_NeoPixel(NUM_LEDS, LED_PIN, NEO_GRB + NEO_KHZ800);

float smoothedBrightness = 0;  // Store previous brightness for smoothing

void setup() {
    CircuitPlayground.begin();
    strip.begin();
    Serial.begin(115200);

    // Ensure all LEDs start off
    strip.clear();
    CircuitPlayground.clearPixels();
    strip.show();

    Serial.println("Setup complete: NeoPixel strip initialized and turned off.");
}

void loop() {
    int sensorValue = analogRead(stretchSensorPin);
    Serial.print("Raw Sensor Value: ");
    Serial.println(sensorValue);
    
    // Map sensor value to LED brightness (0 = off)
    int targetBrightness = map(sensorValue, maxSensorValue, minSensorValue, 0, 255);
    targetBrightness = constrain(targetBrightness, 0, 255);  

    // Apply smoothing (low-pass filter)
    smoothedBrightness = smoothedBrightness * 0.85 + targetBrightness * 0.15;  // Adjust smoothing factor if needed

    // Ensure the lights fully turn off when needed
    uint32_t color = (smoothedBrightness > 0) ? strip.Color(smoothedBrightness, smoothedBrightness * 0.6, smoothedBrightness * 0.2) : strip.Color(0, 0, 0);

    // Set onboard NeoPixels
    for (int i = 0; i < 10; i++) {
        CircuitPlayground.setPixelColor(i, color);
    }

    // Set external NeoPixel strip
    for (int i = 0; i < NUM_LEDS; i++) {
        strip.setPixelColor(i, color);
    }
    strip.show(); // Update the external LEDs

    delay(50);  // Reduced delay for smoother transitions
}
